#
# spec file for package trackballs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           trackballs
Version:        1.3.1
Release:        bp155.2.11
Summary:        A Marble Madness-like Game
License:        GPL-2.0-only
Group:          Amusements/Games/3D/Other
URL:            https://trackballs.github.io/
Source0:        https://github.com/trackballs/trackballs/archive/v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  guile-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(zlib)
Obsoletes:      %{name}-music
Obsoletes:      %{name}-music-extra

%description
Trackballs is a game similar to the classic "Marble Madness" game
on the Amiga from the 80s. The player collects points by steering a
marble ball through a labyrinth filled with vicious hammers, pools of
acid, and other obstacles.

%prep
%setup -q

%build
%cmake \
    -DTRACKBALLS_DOC_DIR=%{_docdir}/%{name}
make %{?_smp_mflags}

%install
%cmake_install
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%{_docdir}/%{name}
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_datadir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/trackballs.*

%changelog
* Wed Nov 21 2018 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.3.1:
  * CMakeLists fix to install paths for icons and documentation
  * Callbacks are delayed until the end of the physics tick
  * Updated manpage
  * Reduced image loading and memory use on startup
  * Minor difficulty adjustments to fourSeasons_4, ds3, con4.
  * Build is now reproducible
  * further bug fixes and performance improvements
- remove patch:
  * trackballs-icons.patch: fix included in release
- use guile-devel to make transition to Guile 2.2 easier
* Thu May  3 2018 rpm@fthiessen.de
- Fixed Leap build
  * Unknown license
  * Unknown macro
* Wed May  2 2018 jengelh@inai.de
- Update descriptions.
* Wed Apr 18 2018 tchvatal@suse.com
- Version update to 1.3.0 bsc#1045250:
  * Porting to SDL2, Guile 2, OpenGL standard 3.3
  * Switching to CMake for a build system
  * Pulling music into the main repository
  * Handle level scripting errors without crashing
  * Changed level entity position coordinates to be internally consistent
    (and adjusted all the levels to match)
- Add patch to fix svg icon location trackballs-icons.patch
* Wed Apr 18 2018 tchvatal@suse.com
- Drop all upstreamed patches:
  * fix-gcc-6.patch
  * trackballs-1.1.4-bufferoverflow.diff
  * trackballs-1.1.4-codecleanup.diff
  * trackballs-1.1.4-guile20.patch
  * trackballs-off_by_one.diff
  * void-funcs.diff
* Sun Jul 31 2016 rpm@fthiessen.de
- Added fix-gcc-6.patch for fixing the build with gcc >= 6.0
- Split music packages because
* Sat Jan 26 2013 joop.boonen@opensuse.org
- Dropped all permission scripts
- Installed the binary in /usr/bin and the default data directory
* Fri Jan 18 2013 joop.boonen@opensuse.org
- run_permissions is obsolete, not supported in openSUSE > 12.2
* Fri May 25 2012 joop.boonen@opensuse.org
- Added missing BuildRequires automake
- Using Fedora guile 2.0 patch
- Cleaned the spec file up
* Fri Mar 23 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant sections/tags
* Tue Oct 18 2011 coolo@suse.com
- give guile2 port a shot - gave up
* Thu Dec  9 2010 rguenther@novell.com
- drop bogus libstdc++ BuildRequires
* Sun Mar  7 2010 coolo@novell.com
- fix build with gcc 4.5
* Mon Sep 24 2007 bk@suse.de
- remove tb_design,genesis.ogg (old, new songs were added, saves 7MB)
* Fri Aug 10 2007 bk@suse.de
- Update to 1.1.4 (much for fun wit new music), major points are:
  * Added great new songs and level sets by Attila Boros
  * Added custom backgrounds in the setup game mode for each levelset
  * Huge improvements in the map editor
* Mon Jul  2 2007 aj@suse.de
- Fix typo in last change.
* Fri Jun 29 2007 pth@suse.de
- BuidRequire SDL_ttf-devel
* Wed Oct 18 2006 pth@suse.de
- Fix an off-by-one bug.
* Fri Oct 13 2006 aj@suse.de
- Add guile-devel to buildrequires.
* Thu Oct 12 2006 ro@suse.de
- added gmp-devel to buildreq (guile)
* Mon Jan 30 2006 pth@suse.de
- Add gcc-c++ and libstdc++ to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 17 2005 sndirsch@suse.de
- updated to release 1.1.1
- adjusted codecleanup patch
* Tue May  3 2005 pth@suse.de
- Fix pointer->int casts.
- Fix the use of uninitialized variables.
- Reduce compiler warnings.
* Wed Mar  2 2005 sndirsch@suse.de
- merged trackballs/trackballs-music
* Wed Aug 25 2004 bk@suse.de
- fix the last return code patch, the return false was wrong
* Wed May 26 2004 ro@suse.de
- added some return values to non-void functions
* Tue Feb 10 2004 sndirsch@suse.de
- updated to release 1.0.0
- removed patch (no longer required)
- removed "-ffast-math"; does not work any longer with 1.0.0
* Wed Nov  5 2003 ro@suse.de
- package according to permissions.secure and add run_permissions
* Mon Aug 25 2003 ro@suse.de
- fix compile with current gcc
* Tue Aug 12 2003 sndirsch@suse.de
- added desktop icon
* Mon Aug 11 2003 bk@suse.de
- Updated to 0.9.0
* Sun Aug 10 2003 sndirsch@suse.de
- added desktop file
* Mon Jun  2 2003 ro@suse.de
- fix build without platform-prefixed binaries
* Thu Mar 13 2003 bk@suse.de
- fix highscore saving if score is in /var, fixes bug number 25256
* Mon Mar  3 2003 bk@suse.de
- 0.7.1: fix small bugs, add jump height, antialisasing for map-grid
* Mon Feb 24 2003 bk@suse.de
- 0.7.0: fix textures, new pipe level, diagonal keys added, and mm.
* Mon Feb 17 2003 bk@suse.de
- 0.6.0: health bar, pipes, pipe connectors, save points, help screen
* Mon Feb 10 2003 bk@suse.de
- initial version: 0.5.1
